import 'option.dart';
import 'terminal.dart';

// A single instance of Terminal to be re-used. If this declaration was inside the prompter class
// a new terminal would be created for every new instance of Prompter which is unnecessary.
// _terminal is a private variable that cannot be accessed outside of the lib directory
final Terminal _terminal = const Terminal();

class Prompter {
  // @askBinary only for yes or no questions
  bool askBinary(String prompt) {
    final input = _ask('$prompt (y/n)', []);                                       // empty list to satisfy param : Enter a choice >
    return input.contains('y') || input.contains('Y');
  }

  // @askMultiple only for multiple choice questions
  // @param prompt is the question that will be asked
  // @param options is the list of options to be printed
  dynamic askMultiple(String prompt, List<Option> options) {
    final input = _ask(prompt, options);

    try {
      // parse input as an int, its initially a string from collectInput, then use that input int which is the same as the label to
      // return the options value
      return options[int.parse(input)].value;
    } catch (err) {
      // if an error is caught then just prompt the user again
      return askMultiple(prompt, options);
    }

  }

  String _ask(String prompt, List<Option> options) {
    _terminal.clearScreen();
    _terminal.printPrompt(prompt);
    _terminal.printOptions(options);

    return _terminal.collectInput();
  }
}