import 'dart:io' as io;
import 'option.dart';  // for type Option

class Terminal {
  // const constructor
  const Terminal();

  // @printPrompt print the param: prompt
  // @stdout is a property of the io lib meaning an existing instance is available, no need for stdout = new Stdout
  // @writeln converts an object to a string and writes the result to this(the terminal), non-blocking
  void printPrompt(String prompt) {
    io.stdout.writeln(prompt);
  }

  // @printOptions loops through options and writes them out, then writes a prompt for the user to enter a choice
  // @param options is a list of Option objects
  // @.asMap turns the list into a map were we can reference the index
  void printOptions(List<Option> options) {
    options.asMap().forEach((index, option) {
      io.stdout.writeln('[$index] - ${option.label}');
    });

    io.stdout.writeln('Enter a choice\n');
    io.stdout.write('>');
  }

  // @collectInput collects input from the user
  // @readLineSync synchronously reads a line from stdin and returns it on enter. This where the user types in an option.
  String collectInput() {
    return io.stdin.readLineSync();
  }

  // @clearScreen clear the current terminal window
  // @Platform provides information such as the OS, each OS & terminal has its own way of clearing the screen
  // @write inserts a string into this(the terminal), unlike writeln is does not insert a new empty line
  void clearScreen() {
    if(io.Platform.isWindows) {
      io.stdout.write('\x1B[2J\x1B[0f');
    } else {
      io.stdout.write('\x1B[2J\x1B[3J\x1B[H');
    }
  }
}